import { useState, useEffect } from 'react';

function useMediaQuery(queryInput, _temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      _ref$defaultMatches = _ref.defaultMatches,
      defaultMatches = _ref$defaultMatches === void 0 ? false : _ref$defaultMatches;

  var hasSupportMatchMedia = typeof window !== 'undefined' && typeof window.matchMedia !== 'undefined';
  var matchMedia = hasSupportMatchMedia ? window.matchMedia : null;
  var query = queryInput.replace(/^@media( ?)/m, '');

  var _useState = useState(function () {
    if (hasSupportMatchMedia) return matchMedia(query).matches;
    return defaultMatches;
  }),
      match = _useState[0],
      setMatch = _useState[1];

  useEffect(function () {
    var active = true;
    if (!hasSupportMatchMedia) return;
    var queryList = matchMedia(query);

    var updateMatch = function updateMatch() {
      if (active) setMatch(queryList.matches);
    };

    updateMatch();
    queryList.addListener(updateMatch);
    return function () {
      active = false;
      queryList.removeListener(updateMatch);
    };
  }, [query, matchMedia, hasSupportMatchMedia]);
  return match;
}

export default useMediaQuery;